<?php
/**
 * Extend module controls
 *
 * @package   WP Grid Builder - Beaver Builder
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Beaver_Builder\Includes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Extend
 *
 * @class WP_Grid_Builder_Beaver_Builder\Includes\Extend
 * @since 1.0.0
 */
final class Extend {

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		add_filter( 'fl_builder_register_settings_form', [ $this, 'settings_form' ], 10, 2 );
		add_filter( 'fl_builder_render_css_module', [ $this, 'css_module' ], 10, 3 );

	}

	/**
	 * Add settings in module form
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array   $form Hold settings form.
	 * @param integer $id   Module ID.
	 */
	public function settings_form( $form, $id ) {

		$providers = array_keys( apply_filters( 'wp_grid_builder_beaver_builder/providers', [] ) );

		if ( in_array( $id, $providers, true ) ) {

			$section = [
				'wp_grid_builder' => [
					'title'  => 'WP Grid Builder',
					'fields' => [
						'wpgb_fading' => [
							'type'    => 'select',
							'label'   => __( 'Fading Animation', 'wpgb-beaver-builder' ),
							'preview' => [],
							'default' => 0,
							'options' => [
								0 => __( 'No', 'wpgb-beaver-builder' ),
								1 => __( 'Yes', 'wpgb-beaver-builder' ),
							],
						],
					],
				],
			];

			reset( $form );
			$tab = key( $form );

			if ( ! empty( $form[ $tab ]['sections'] ) ) {

				$form[ $tab ]['sections'] = array_merge(
					array_slice( $form[ $tab ]['sections'], 0, 1 ),
					$section,
					array_slice( $form[ $tab ]['sections'], 1 )
				);
			}
		}

		return $form;

	}

	/**
	 * Add settings in module form
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param string $module_css Module CSS.
	 * @param object $module     Module instance.
	 * @param object $settings   Module settings.
	 */
	public function css_module( $module_css, $module, $settings ) {

		$providers = array_keys( apply_filters( 'wp_grid_builder_beaver_builder/providers', [] ) );

		if (
			empty( $module->node ) ||
			empty( $module->slug ) ||
			! in_array( $module->slug, $providers, true )
		) {
			return $module_css;
		}

		$module_css .= sprintf(
			'.fl-node-%1$s {
				outline: none;
			}',
			sanitize_html_class( $module->node )
		);

		if ( ! empty( $settings->wpgb_fading ) ) {

			$module_css .= sprintf(
				'.fl-node-%1$s {
					transition: all 0.35s ease;
				}
				.fl-node-%1$s.wpgb-loading {
					opacity: 0.35;
				}',
				sanitize_html_class( $module->node )
			);
		}

		return $module_css;

	}
}
