<?php
/**
 * Module
 *
 * @package   WP Grid Builder - Beaver Builder
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Beaver_Builder\Includes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Module
 *
 * @class WP_Grid_Builder_Beaver_Builder\Includes\Module
 * @since 1.0.0
 */
final class Module {

	/**
	 * Holds template attributes
	 *
	 * @since 1.0.0
	 * @access protected
	 * @var array
	 */
	protected $template = [];

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $template Holds template attributes.
	 */
	public function __construct( $template ) {

		$this->template = $template;

	}

	/**
	 * Parse Beaver Builder modules to match the one filterable
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function get_content() {

		$modules = $this->get_modules();

		foreach ( $modules as $module ) {

			$content = $this->get_module( (object) $module );

			if ( ! empty( $content ) ) {
				break;
			}
		}

		return $content;

	}

	/**
	 * Get content from Beaver Builder
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array
	 */
	public function get_modules() {

		// If we render facets in the editor.
		if ( ! empty( $this->template['modules'] ) ) {
			return (array) $this->template['modules'];
		}

		if ( empty( $this->template['post_id'] ) ) {
			return [];
		}

		\FLBuilderModel::set_post_id( $this->template['post_id'] );

		return (array) \FLBuilderModel::get_nodes();

	}

	/**
	 * Get filterable module
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $module Holds module attributes.
	 */
	public function get_module( $module ) {

		if ( ! isset( $module->node, $module->settings ) ) {
			return;
		}

		if ( 'bb-module-' . $module->node !== $this->template['id'] ) {
			return;
		}

		$module->settings = (object) $module->settings;
		// Inject template settings.
		$module->settings->wpgb = $this->template;

		ob_start();
		\FLBuilder::render_module( $module );
		// Shortcodes are not rendered when filtering and rendering a module.
		return do_shortcode( ob_get_clean() );

	}
}
