<?php
/**
 * Observer
 *
 * @package   WP Grid Builder - Beaver Builder
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Beaver_Builder\Includes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Observer
 *
 * @class WP_Grid_Builder_Beaver_Builder\Includes\Observer
 * @since 1.0.0
 */
class Observer {

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		add_action( 'fl_builder_before_render_module', [ $this, 'before_render' ] );
		add_action( 'fl_builder_after_render_module', [ $this, 'after_render' ] );

	}

	/**
	 * Before to render module
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $module Holds module attributes.
	 */
	public function before_render( $module ) {

		// phpcs:ignore WordPress.Security.NonceVerification.Recommended
		if ( isset( $_GET['fl_builder'] ) && ! wpgb_doing_ajax() ) {
			return;
		}

		$this->maybe_handle( $module->slug, $module );

	}

	/**
	 * After to render module
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $module Holds module attributes.
	 */
	public function after_render( $module ) {

		// phpcs:ignore WordPress.Security.NonceVerification.Recommended
		if ( isset( $_GET['fl_builder'] ) && ! wpgb_doing_ajax() ) {
			return;
		}

		return $this->maybe_render( $module->slug, $module );

	}
}
