<?php
/**
 * Post Carousel
 *
 * @package   WP Grid Builder - Beaver Builder
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Beaver_Builder\Includes\Providers;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Post Carousel module
 *
 * @class WP_Grid_Builder_Beaver_Builder\Includes\Providers\Post_Carousel
 * @since 1.0.0
 */
final class Post_Carousel extends Provider {

	/**
	 * Module options
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array
	 */
	public function options() {

		return array_merge(
			parent::options(),
			[
				'itemSelector'       => '.fl-post-carousel-post',
				'module'             => 'post-carousel',
				'layout'             => isset( $this->module->layout ) ? $this->module->layout : 'grid',
				'navigationControls' => isset( $this->module->navigation ) && 'yes' === $this->module->navigation,
				'slideWidth'         => ! empty( $this->module->slide_width ) ? (int) $this->module->slide_width : 300,
				'settings'           => [
					'mode'           => 'horizontal',
					'pager'          => isset( $this->module->pagination ) && 'no' !== $this->module->pagination,
					'auto'           => ! empty( $this->module->auto_play ) && 'true' === $this->module->auto_play,
					'pause'          => ! empty( $this->module->speed ) ? $this->module->speed * 1000 : '1000',
					'speed'          => ! empty( $this->module->transitionDuration ) ? (int) $this->module->transitionDuration * 1000 : 1000,
					'autoDirection'  => isset( $this->module->direction ) ? $this->module->direction : 'next',
					'infiniteLoop'   => isset( $this->module->carousel_loop ) && 'true' === $this->module->carousel_loop,
					'adaptiveHeight' => true,
					'controls'       => false,
					'autoHover'      => true,
					'slideMargin'    => isset( $this->module->space_between ) && '' !== $this->module->space_between ? (int) $this->module->space_between : 30,
					'moveSlides'     => isset( $this->module->move_slides ) ? (int) $this->module->move_slides : 1,
				],
			]
		);
	}
}
