<?php // phpcs:ignore WordPress.Files.FileName.InvalidClassFileName
/**
 * Facet module
 *
 * @package   WP Grid Builder - Beaver Builder
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Beaver_Builder\Modules;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Facet module
 *
 * @class WP_Grid_Builder_Beaver_Builder\Modules\Facet
 * @since 1.0.0
 */
final class Facet extends \FLBuilderModule {

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		parent::__construct(
			[
				'name'            => __( 'Facet', 'wpgb-beaver-builder' ),
				'description'     => __( 'WP Grid Builder facet', 'wpgb-beaver-builder' ),
				'category'        => 'WP Grid Builder',
				'partial_refresh' => true,
			]
		);
	}

	/**
	 * Module icon
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param string $icon Module icon.
	 * @return string
	 */
	public function get_icon( $icon = '' ) {

		return '<svg viewBox="0 0 20 20"><path d="M13.948 3.71a.583.583 0 0 0-.448-.21h-7a.583.583 0 0 0-.448.21l-2.917 3.5a.584.584 0 0 0-.023.718l6.417 8.75a.584.584 0 0 0 .941 0l6.417-8.75a.583.583 0 0 0-.023-.718Zm.135 4.457H5.917V7h8.167Z"/></svg>';

	}

	/**
	 * Module render
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render() {

		if (
			empty( $this->settings->facet ) ||
			empty( $this->settings->grid )
		) {
			return;
		}

		wpgb_render_facet(
			[
				'id'   => $this->settings->facet,
				'grid' => $this->settings->grid,
			]
		);
	}
}

\FLBuilder::register_module(
	'\WP_Grid_Builder_Beaver_Builder\Modules\Facet',
	[
		'wpgb_tab_facet' => [
			'title'    => __( 'Settings', 'wpgb-beaver-builder' ),
			'sections' => [
				'wpgb_section_facet' => [
					'fields' => include WPGB_BEAVER_BUILDER_PATH . 'modules/settings/facet.php',
				],
			],
		],
	]
);
