<?php // phpcs:ignore WordPress.Files.FileName.InvalidClassFileName
/**
 * Grid module
 *
 * @package   WP Grid Builder - Beaver Builder
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Beaver_Builder\Modules;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Grid module
 *
 * @class WP_Grid_Builder_Beaver_Builder\Modules\Grid
 * @since 1.0.0
 */
final class Grid extends \FLBuilderModule {

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		parent::__construct(
			[
				'name'            => __( 'Grid', 'wpgb-beaver-builder' ),
				'description'     => __( 'WP Grid Builder grid', 'wpgb-beaver-builder' ),
				'category'        => 'WP Grid Builder',
				'partial_refresh' => true,
			]
		);
	}

	/**
	 * Module icon
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param string $icon Module icon.
	 * @return string
	 */
	public function get_icon( $icon = '' ) {

		return '<svg viewBox="0 0 20 20"><path d="M9 17H3v-6h6Zm0-8H3V3h6Zm8 8h-6V3h6Z"/></svg>';

	}

	/**
	 * Whether it renders preview template (popup)
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return boolean
	 */
	public function is_builder() {

		// phpcs:ignore WordPress.Security.NonceVerification.Recommended
		return isset( $_GET['fl_builder'] );

	}

	/**
	 * Widget render
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render() {

		if ( empty( $this->settings->grid ) ) {
			return;
		}

		wpgb_render_grid(
			array_merge(
				[ 'id' => $this->settings->grid ],
				$this->default_query(),
				$this->is_builder() ? [ 'inline_style' => true ] : []
			)
		);

		$this->enqueue_grid_assets();

	}

	/**
	 * Get default editor query to simulate main query.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array
	 */
	public function default_query() {

		$query_args['is_main_query'] = ! empty( $this->settings->is_main_query );

		if ( ! $this->is_builder() ) {
			return $query_args;
		}

		if ( ! $query_args['is_main_query'] ) {
			return $query_args;
		}

		$post_types = get_post_types( [ 'public' => true ] );
		unset( $post_types['attachment'] );

		return [
			'post_type'   => $post_types,
			'post_status' => 'publish',
		];
	}

	/**
	 * Enqueue widget styles in editor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function enqueue_grid_assets() {

		// We do not enqueue on frontend pages.
		if ( ! $this->is_builder() ) {
			return;
		}

		// Enqueue plugin styles.
		wpgb_enqueue_styles();

		// Add inline styles generated by a grid only.
		$styles = wp_styles();
		$styles->print_inline_style( WPGB_SLUG . '-style' );
		$styles->do_item( WPGB_SLUG . '-grids' );
		$styles->do_item( WPGB_SLUG . '-fonts' );

	}
}

\FLBuilder::register_module(
	'\WP_Grid_Builder_Beaver_Builder\Modules\Grid',
	[
		'wpgb_tab_grid' => [
			'title'    => __( 'Settings', 'wpgb-beaver-builder' ),
			'sections' => [
				'wpgb_section_grid' => [
					'fields' => include WPGB_BEAVER_BUILDER_PATH . 'modules/settings/grid.php',
				],
			],
		],
	]
);
