<?php
/**
 * WP Grid Builder Beaver Builder Add-on
 *
 * @package   WP Grid Builder - Beaver Builder
 * @author    Loïc Blascos
 * @link      https://www.wpgridbuilder.com
 * @copyright 2019-2022 Loïc Blascos
 *
 * @wordpress-plugin
 * Plugin Name:  WP Grid Builder - Beaver Builder
 * Plugin URI:   https://www.wpgridbuilder.com
 * Description:  Integrate WP Grid Builder with Beaver Builder plugin.
 * Version:      1.0.3
 * Author:       Loïc Blascos
 * Author URI:   https://www.wpgridbuilder.com
 * License:      GPL-3.0-or-later
 * License URI:  https://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:  wpgb-beaver-builder
 * Domain Path:  /languages
 */

namespace WP_Grid_Builder_Beaver_Builder;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

define( 'WPGB_BEAVER_BUILDER_VERSION', '1.0.3' );
define( 'WPGB_BEAVER_BUILDER_FILE', __FILE__ );
define( 'WPGB_BEAVER_BUILDER_BASE', plugin_basename( WPGB_BEAVER_BUILDER_FILE ) );
define( 'WPGB_BEAVER_BUILDER_PATH', plugin_dir_path( WPGB_BEAVER_BUILDER_FILE ) );
define( 'WPGB_BEAVER_BUILDER_URL', plugin_dir_url( WPGB_BEAVER_BUILDER_FILE ) );

require_once WPGB_BEAVER_BUILDER_PATH . 'includes/class-autoload.php';

/**
 * Load plugin text domain.
 *
 * @since 1.0.0
 */
function textdomain() {

	load_plugin_textdomain(
		'wpgb-beaver-builder',
		false,
		basename( dirname( WPGB_BEAVER_BUILDER_FILE ) ) . '/languages'
	);

}
add_action( 'plugins_loaded', __NAMESPACE__ . '\textdomain' );

/**
 * Plugin compatibility notice.
 *
 * @since 1.0.0
 */
function plugin_notice() {

	$notice = __( '<strong>Gridbuilder ᵂᴾ - Beaver Builder</strong> add-on requires at least <code>Gridbuilder ᵂᴾ v1.6.5</code>. Please update Gridbuilder ᵂᴾ to use Beaver Builder add-on.', 'wpgb-beaver-builder' );

	echo '<div class="error">' . wp_kses_post( wpautop( $notice ) ) . '</div>';

}

/**
 * Beaver Builder compatibility notice.
 *
 * @since 1.0.0
 */
function beaver_builder_notice() {

	$notice = __( '<strong>Gridbuilder ᵂᴾ - Beaver Builder</strong> add-on requires at least <code>Beaver Builder v2.5.0</code>. Please update and activate Beaver Builder.', 'wpgb-beaver-builder' );

	echo '<div class="error">' . wp_kses_post( wpautop( $notice ) ) . '</div>';

}

/**
 * Initialize plugin
 *
 * @since 1.0.0
 */
function loaded() {

	if ( version_compare( WPGB_VERSION, '1.6.5', '<' ) ) {

		add_action( 'admin_notices', __NAMESPACE__ . '\plugin_notice' );
		return;

	}

	if ( ! class_exists( 'FLBuilder' ) || version_compare( FL_BUILDER_VERSION, '2.5.0', '<' ) ) {

		add_action( 'admin_notices', __NAMESPACE__ . '\beaver_builder_notice' );
		return;

	}

	new Includes\Plugin();

}
add_action( 'wp_grid_builder/loaded', __NAMESPACE__ . '\loaded' );
